@@ -9,6 +9,12 @@ class TestMDLTypesHelper(ModelIO.NSObject):
 
 
 class TestMDLTypes(TestCase):
+    def test_enum_types(self):
+        self.assertIsEnumType(ModelIO.MDLDataPrecision)
+        self.assertIsEnumType(ModelIO.MDLGeometryType)
+        self.assertIsEnumType(ModelIO.MDLIndexBitDepth)
+        self.assertIsEnumType(ModelIO.MDLProbePlacement)
+
     def testConstants(self):
         self.assertIsInstance(ModelIO.kUTTypeAlembic, str)
         self.assertIsInstance(ModelIO.kUTType3dObject, str)
@@ -47,9 +53,9 @@ class TestMDLTypes(TestCase):
         self.assertIsInstance(ModelIO.kUTTypeUniversalSceneDescriptionMobile, str)
 
     def testProtocolObjects(self):
-        objc.protocolNamed("MDLNamed")
-        objc.protocolNamed("MDLComponent")
-        objc.protocolNamed("MDLObjectContainerComponent")
+        self.assertProtocolExists("MDLNamed")
+        self.assertProtocolExists("MDLComponent")
+        self.assertProtocolExists("MDLObjectContainerComponent")
 
     def testMethods(self):
         self.assertArgHasType(
@@ -58,4 +64,10 @@ class TestMDLTypes(TestCase):
 
     @expectedFailure
     def testStructs(self):
-        self.fail("MDLAxisAlignedBoundingBox is SIMD type")
+        self.assertEqual(
+            ModelIO.MDLAxisAlignedBoundingBox.__typestr__,
+            b"{_MDLAxisAlignedBoundingBox=<3f><3f>}",
+        )
+        v = ModelIO.MDLAxisAlignedBoundingBox()
+        self.assertIs(v.maxBounds, None)
+        self.assertIs(v.minBounds, None)
